@@ -1,9 +1,6 @@
 ## no critic (RequireUseStrict)
 package Dist::Zilla::Plugin::Git::ExcludeUntracked;
-{
-  $Dist::Zilla::Plugin::Git::ExcludeUntracked::VERSION = '0.03';
-}
-
+$Dist::Zilla::Plugin::Git::ExcludeUntracked::VERSION = '0.04';
 ## use critic (RequireUseStrict)
 use Moose;
 use File::Find;
@@ -63,17 +60,17 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
-
-
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Dist::Zilla::Plugin::Git::ExcludeUntracked - Excludes untracked files from your dist
+Dist::Zilla::Plugin::Git::ExcludeUntracked - Excludes untracked files from your dist [DEPRECATED]
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -81,17 +78,11 @@ version 0.03
 
 =head1 DESCRIPTION
 
+B<NOTE> This module is deprecated in favor of L<Dist::Zilla::Plugin::Git::GatherDir>.
+
 This L<Dist::Zilla> plugin automatically excludes any files from your
 distribution that are not currently tracked by Git.
 
-=head1 COMPARED TO GIT::GATHERDIR
-
-There's another plugin that provides similar functionality:
-L<Dist::Zilla::Plugin::Git::GatherDir>.  The chief difference is that
-while this plugin is designed to work in concert with
-L<Dist::Zilla::Plugin::GatherDir>, C<Git::GatherDir> is designed to work
-as a replacement for C<GatherDir>.
-
 =head1 SEE ALSO
 
 L<Dist::Zilla>, L<Dist::Zilla::Plugin::Git::GatherDir>
@@ -128,8 +119,7 @@ feature.
 
 =cut
 
-
 __END__
 
-# ABSTRACT:  Excludes untracked files from your dist
+# ABSTRACT:  Excludes untracked files from your dist [DEPRECATED]
 
